@@ -1,9 +1,9 @@
 """Define interfaces for your add-on.
 """
-from plone.theme.interfaces import IDefaultPloneLayer
+from collective.flexitopic.interfaces import IFlexiTopicLayer
 from collective.geo.kml.interfaces import IKMLOpenLayersViewlet
 
-class IGeoFlexiTopicLayer(IDefaultPloneLayer):
+class IGeoFlexiTopicLayer(IFlexiTopicLayer):
     """Marker interface that defines a Zope 3 browser layer.
     """
 
@@ -11,3 +11,7 @@ class IGeoFlexiTopicLayer(IDefaultPloneLayer):
 class IGeoFlexiTopicViewlet(IKMLOpenLayersViewlet):
     """ Marker interface for browser.flexitopicview.MapViewlet
     """
+
+class IGeoFlexiTopicPortletViewlet(IGeoFlexiTopicViewlet):
+    """ Marker interface for browser.flexitopicview.MapViewlet
+    """
